@@ -2,10 +2,8 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakti",
-    "Download" : "Preuzmi",
     "Send email" : "Pošalji e-poštu",
-    "Groups" : "Grupe",
-    "Group name" : "Naziv grupe",
+    "Download" : "Preuzmi",
     "Rename" : "Preimenuj",
     "Enabled" : "Aktivirano",
     "Delete" : "Obriši",
@@ -15,13 +13,14 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Spremi",
     "Description" : "Opis",
+    "Cancel" : "Otkaži",
     "Invalid image" : "Nevažeća datoteka",
     "Name" : "Ime",
     "Title" : "Naslov",
-    "Cancel" : "Otkaži",
     "New contact" : "Novi kontakt",
     "Personal circle" : "Osobni krug",
     "Pending" : "Na čekanju",
+    "None" : "Ništa",
     "Close" : "Zatvori",
     "Import" : "Uvoz",
     "Not grouped" : "Nije grupirano",
@@ -33,8 +32,8 @@ OC.L10N.register(
     "Admin" : "Administrator",
     "Owner" : "Vlasnik",
     "Users" : "Korisnici",
-    "Nickname" : "Nadimak",
     "Additional names" : "Dodatna imena",
+    "Nickname" : "Nadimak",
     "Notes" : "Notes",
     "Website" : "Web-prezentacija",
     "Location" : "Lokacija",
@@ -53,7 +52,6 @@ OC.L10N.register(
     "Fax" : "Faks",
     "Pager" : "Dojavljivač",
     "Voice" : "Glas",
-    "None" : "Ništa",
     "Unknown" : "Nepoznato"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
