@@ -8,11 +8,9 @@ OC.L10N.register(
     "Loading …" : "Уншиж байна...",
     "Add member" : "Гишүүн нэмэх",
     "Delete circle" : "бүлгийг устгах",
-    "Download" : "Татаж авах",
-    "Groups" : "Багууд",
-    "Group name" : "Бүлгийн нэр",
     "Circles" : "Тойрог",
     "Create a new circle" : "шинэ бүлэг үүсгэх",
+    "Download" : "Татаж авах",
     "Rename" : "Нэр солих",
     "Enabled" : "Идэвхижүүлэх",
     "Delete" : "Устгах",
@@ -28,21 +26,21 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Хадгалах",
     "Description" : "Тайлбар",
+    "Cancel" : "болиулах",
     "Upload a new picture" : "Шинэ зураг оруулах",
     "Choose from Files" : "Файлаас сонгох",
     "Download picture" : "Зураг татаж авах",
     "Delete picture" : "Зураг устгах",
     "Invalid image" : "буруу зураг",
-    "Image is too big (max 1MB)." : "Зургийн хэмжээ их /max 1MB/",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
     "Select address book" : "Хаягийн бүртгэл сонгох",
-    "Cancel" : "болиулах",
     "Address book" : "Хаягийн бүртгэл",
     "New contact" : "Шинэ харилцагч",
     "No results" : "Үр дүн байхгүй",
     "Personal circle" : "Хувийн тойрог",
     "Pending" : "Хүлээгдэж байгаа",
+    "None" : "юу ч үгүй",
     "Close" : "Хаах",
     "Import" : "Импорт",
     "Not grouped" : "Багт ороогүй",
@@ -55,9 +53,9 @@ OC.L10N.register(
     "Admin" : "Админ",
     "Owner" : "Эзэмшигч",
     "Users" : "хэрэглэгч",
-    "Nickname" : "Товч нэр",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
+    "Nickname" : "Товч нэр",
     "Notes" : "Тэмдэглэл",
     "Website" : "Цахим хуудас",
     "Location" : "Байршил",
@@ -91,7 +89,6 @@ OC.L10N.register(
     "Gender" : "Хүйс",
     "Female" : "Эмэгтэй",
     "Male" : "Эрэгтэй",
-    "None" : "юу ч үгүй",
     "Unknown" : "Үл танигдах зүйл",
     "Time zone" : "Цагийн бүс"
 },
